@@ -25,7 +25,7 @@ import textwrap
 
 version = "";
 needs_cleanup = False
-packaged_by = "Matthias Klose <doko\@ubuntu.com>";
+packaged_by = "Matthias Klose <doko@ubuntu.com>";
 common_licenses = {};
 
 ## TODO: Can the script deduce this list?
@@ -52,21 +52,20 @@ excluded_files = [
 
 ## TODO: Can the script deduce this list?
 openjdk_copyrights = [
-  "Copyright (c) 1996-2025 Oracle and/or its affiliates.",
+  "Copyright (c) 1996-2026 Oracle and/or its affiliates.",
   "Copyright (c) 1996-2003 Sun Microsystems, Inc.",
-  "Copyright (c) 2009-2012 Red Hat, Inc.",
-  "Copyright (c) 2012-2022 SAP SE.",
-  "Copyright (c) 2020-2021 Azul Systems, Inc.",
+  "Copyright (c) 2009-2025 Red Hat, Inc.",
+  "Copyright (c) 2012-2026 SAP SE.",
+  "Copyright (c) 2020-2023 Azul Systems, Inc.",
   "Copyright (c) 1999-2022 The Apache Software Foundation.",
   "Copyright (c) 2020-2021 Microsoft Corporation",
-  "Copyright (c) 2009-2022 Google LLC",
+  "Copyright (c) 2009-2026 Google LLC",
   "Copyright (c) 2020-2021 Amazon.com, Inc",
-  "Copyright (c) 2021 Alibaba Group Holding Limited",
-  "Copyright (c) 2019-2021 Huawei Technologies Co. Ltd.",
-  "Copyright (c) 2021-2023 BELLSOFT",
+  "Copyright (c) 2014-2025 Alibaba Group Holding Limited",
+  "Copyright (c) 2019-2025 Huawei Technologies Co. Ltd.",
+  "Copyright (c) 2021-2025 BELLSOFT",
   "Copyright (c) 2022-23 THL A29 Limited, a Tencent company.",
-  "Copyright (c) 2021-2023, Arm Limited.",
-  "Copyright (C) 2014-2017 by Vitaly Puzrin and Andrei Tuputcyn.",
+  "Copyright (c) 2021-2025, Arm Limited.",
   "Copyright (c) 2017 Instituto de Pesquisas Eldorado.",
   "Copyright (c) 1999-2007  Brian Paul.",
   "Copyright (c) 2018-2019 Adobe Inc.",
@@ -75,6 +74,7 @@ openjdk_copyrights = [
   "Portions Copyright (c) 2011-2014 IBM Corporation",
   "Portions Copyright (c) 1995  Colin Plumb",
   "Portions Copyright (c) 1997-2003 Eastman Kodak Company",
+  "Copyright (C) 2020-2025 Datadog, Inc",
   "See other third party notices under the License section"
 ]
 
@@ -285,7 +285,7 @@ def main():
   version = detect_version()
 
   sys.stdout = open('./debian/copyright', 'w')
-  supported_versions = ["11", "17", "21", "22", "23", "24", "25", "26"]
+  supported_versions = ["11", "17", "21", "22", "23", "24", "25", "26", "27"]
 
   if version in supported_versions:
     generate_copyright()
